@@ -36,7 +36,7 @@ class BatchProcessImagesItem;
 
 class ColorImagesDialog : public BatchProcessImagesDialog
 {
-Q_OBJECT
+TQ_OBJECT
   
 
  public:
