@@ -67,7 +67,7 @@ OutputDialog::OutputDialog(TQWidget* parent, TQString caption, TQString Messages
     m_helpButton = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Plugin Handbooks"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbooks"), this, TQ_SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 
     //---------------------------------------------
@@ -85,8 +85,8 @@ OutputDialog::OutputDialog(TQWidget* parent, TQString caption, TQString Messages
     debugView->append( Messages );
     dvlay->addWidget( debugView );
 
-    connect(this, TQT_SIGNAL(user1Clicked()),
-            this, TQT_SLOT(slotCopyToCliboard()));
+    connect(this, TQ_SIGNAL(user1Clicked()),
+            this, TQ_SLOT(slotCopyToCliboard()));
 
     resize( 600, 400 );
 }
