@@ -43,7 +43,7 @@ namespace KIPIBatchProcessImagesPlugin
 
 class OutputDialog : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
