@@ -42,7 +42,7 @@ namespace KIPIBatchProcessImagesPlugin
 
 class RecompressOptionsDialog : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
  public:
