@@ -45,7 +45,7 @@ class RenameImagesWidget;
 
 class RenameImagesDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
