@@ -33,7 +33,7 @@ namespace KIPICalendarPlugin {
 */
 class CalFormatter : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 
