@@ -40,7 +40,7 @@ class MonthWidget;
 
 class CalSelect : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
