@@ -149,7 +149,7 @@ CalWizard::CalWizard( KIPI::Interface* interface, TQWidget *parent )
     m_helpButton = helpButton();
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQ_SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 
     // ------------------------------------------
@@ -159,8 +159,8 @@ CalWizard::CalWizard( KIPI::Interface* interface, TQWidget *parent )
 
     formatter_ = new CalFormatter();
 
-    connect(this, TQT_SIGNAL(selected(const TQString&)),
-            TQT_SLOT(slotPageSelected(const TQString&)));
+    connect(this, TQ_SIGNAL(selected(const TQString&)),
+            TQ_SLOT(slotPageSelected(const TQString&)));
 
     setCaption(i18n("Create Calendar"));
 }
@@ -265,7 +265,7 @@ void CalWizard::slotPageSelected(const TQString&)
 
         CalParams& params = cSettings_->calParams;
 
-        // Qt::Orientation
+        // Orientation
         switch (params.imgPos) {
         case(CalParams::Top): {
             printer_->setOrientation(KPrinter::Portrait);
@@ -335,13 +335,13 @@ void CalWizard::slotPrintOnePage()
 
     int angle = interface_->info( image ).angle();
 
-    cb_ = new CalBlockPainter(TQT_TQOBJECT(this), cSettings_->getYear(), month,
+    cb_ = new CalBlockPainter(this, cSettings_->getYear(), month,
                               image, angle, formatter_, painter_);
 
-    connect(cb_, TQT_SIGNAL(signalCompleted()),
-            TQT_SLOT(slotPrintOnePage()));
-    connect(cb_, TQT_SIGNAL(signalProgress(int,int)),
-            wFinishProgressCurrent_, TQT_SLOT(setProgress(int,int)));
+    connect(cb_, TQ_SIGNAL(signalCompleted()),
+            TQ_SLOT(slotPrintOnePage()));
+    connect(cb_, TQ_SIGNAL(signalProgress(int,int)),
+            wFinishProgressCurrent_, TQ_SLOT(setProgress(int,int)));
 }
 
 }  // NameSpace KIPICalendarPlugin
