@@ -151,7 +151,7 @@ DisplayCompare::DisplayCompare(TQWidget* parent, KIPI::Interface* interface,
     m_helpButton = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQ_SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
 
     // ----------------------------------------------------
@@ -166,7 +166,7 @@ DisplayCompare::DisplayCompare(TQWidget* parent, KIPI::Interface* interface,
 
     //---------------------------------------------
 
-    GroupBox1 = new TQGroupBox( 1, Qt::Horizontal, i18n("Original Files"), box );
+    GroupBox1 = new TQGroupBox( 1, TQt::Horizontal, i18n("Original Files"), box );
     GroupBox1->layout()->setSpacing( 6 );
     GroupBox1->layout()->setMargin( 11 );
 
@@ -201,7 +201,7 @@ DisplayCompare::DisplayCompare(TQWidget* parent, KIPI::Interface* interface,
 
     //---------------------------------------------
 
-    GroupBox2 = new TQGroupBox( 1, Qt::Horizontal, i18n("Similar Files"), box );
+    GroupBox2 = new TQGroupBox( 1, TQt::Horizontal, i18n("Similar Files"), box );
     GroupBox2->layout()->setSpacing( 6 );
     GroupBox2->layout()->setMargin( 11 );
 
@@ -262,14 +262,14 @@ DisplayCompare::DisplayCompare(TQWidget* parent, KIPI::Interface* interface,
 
     // signals and slots connections
 
-    connect(this, TQT_SIGNAL(user1Clicked()),
-            this, TQT_SLOT(slotDelete()));
+    connect(this, TQ_SIGNAL(user1Clicked()),
+            this, TQ_SLOT(slotDelete()));
 
-    connect(listName, TQT_SIGNAL(selectionChanged ( TQListViewItem * )),
-            this, TQT_SLOT(slotDisplayLeft(TQListViewItem *)));
+    connect(listName, TQ_SIGNAL(selectionChanged ( TQListViewItem * )),
+            this, TQ_SLOT(slotDisplayLeft(TQListViewItem *)));
 
-    connect(listEq, TQT_SIGNAL(selectionChanged ( TQListViewItem * )),
-            this, TQT_SLOT(slotDisplayRight(TQListViewItem *)));
+    connect(listEq, TQ_SIGNAL(selectionChanged ( TQListViewItem * )),
+            this, TQ_SLOT(slotDisplayRight(TQListViewItem *)));
 
     resize( 700, 600 );
     listName->setSelected(listName->firstChild(), true);
@@ -367,8 +367,8 @@ void DisplayCompare::slotDisplayLeft(TQListViewItem * item)
 
     TDEIO::PreviewJob* thumbJob1 = TDEIO::filePreview( url, preview1->height() );
 
-    connect(thumbJob1, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
-            TQT_SLOT(slotGotPreview1(const KFileItem*, const TQPixmap&)));
+    connect(thumbJob1, TQ_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
+            TQ_SLOT(slotGotPreview1(const KFileItem*, const TQPixmap&)));
 
     FindDuplicateItem *last = NULL;
     TQFile *f = NULL;
@@ -444,8 +444,8 @@ void DisplayCompare::slotDisplayRight(TQListViewItem * item)
 
     TDEIO::PreviewJob* thumbJob2 = TDEIO::filePreview( url, preview2->height() );
 
-    connect(thumbJob2, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
-            TQT_SLOT(slotGotPreview2(const KFileItem*, const TQPixmap&)));
+    connect(thumbJob2, TQ_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
+            TQ_SLOT(slotGotPreview2(const KFileItem*, const TQPixmap&)));
 
     TDEApplication::restoreOverrideCursor();
     }
