@@ -61,7 +61,7 @@ namespace KIPIFindDupplicateImagesPlugin
 
 class  DisplayCompare : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
