@@ -55,7 +55,7 @@ class CompareOperation;
 
 class FindDuplicateImages : public TQObject, public TQThread
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
