@@ -70,7 +70,7 @@ void Plugin_FindImages::setup( TQWidget* widget )
                                                "finddupplicateimages",
                                                0,
                                                this,
-                                               TQT_SLOT(slotFindDuplicateImages()),
+                                               TQ_SLOT(slotFindDuplicateImages()),
                                                actionCollection(),
                                                "findduplicateimages");
 
@@ -101,10 +101,10 @@ void Plugin_FindImages::slotFindDuplicateImages()
 
     if (m_findDuplicateOperation->execDialog())
     {
-        m_progressDlg = new KIPI::BatchProgressDialog(TQT_TQWIDGET(kapp->activeWindow()), i18n("Find Duplicate Images"));
+        m_progressDlg = new KIPI::BatchProgressDialog(kapp->activeWindow(), i18n("Find Duplicate Images"));
 
-        connect(m_progressDlg, TQT_SIGNAL(cancelClicked()),
-                this, TQT_SLOT(slotCancel()));
+        connect(m_progressDlg, TQ_SIGNAL(cancelClicked()),
+                this, TQ_SLOT(slotCancel()));
         m_progressDlg->show();
         m_findDuplicateOperation->compareAlbums();
     }
@@ -282,8 +282,8 @@ void Plugin_FindImages::customEvent(TQCustomEvent *event)
             m_progressDlg->setButtonCancelText( i18n("&Close") );
 #endif
 
-            disconnect(m_progressDlg, TQT_SIGNAL(cancelClicked()),
-                       this, TQT_SLOT(slotCancel()));
+            disconnect(m_progressDlg, TQ_SIGNAL(cancelClicked()),
+                       this, TQ_SLOT(slotCancel()));
 
             m_progressDlg->addedAction(i18n("Displaying results..."),
                                        KIPI::StartingMessage);
