@@ -49,7 +49,7 @@ class ImagesList;
 
 class FlickrWidget : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
