@@ -76,7 +76,7 @@ class ImagesList;
 
 class FlickrWindow : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
