@@ -192,14 +192,14 @@ ImagesList::ImagesList(TQWidget* parent, KIPI::Interface *iface)
 
     // --------------------------------------------------------
 
-    connect(d->addButton, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotAddItems()));
+    connect(d->addButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotAddItems()));
 
-    connect(d->removeButton, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotRemoveItems()));
+    connect(d->removeButton, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotRemoveItems()));
 
-    connect(d->listView, TQT_SIGNAL(signalDropedItems(const KURL::List&)),
-            this, TQT_SLOT(slotAddImages(const KURL::List&)));
+    connect(d->listView, TQ_SIGNAL(signalDropedItems(const KURL::List&)),
+            this, TQ_SLOT(slotAddImages(const KURL::List&)));
 
     // --------------------------------------------------------
 
@@ -250,8 +250,8 @@ void ImagesList::slotAddImages(const KURL::List& list)
 
     TDEIO::PreviewJob *thumbnailJob = TDEIO::filePreview(urls, ICONSIZE);
 
-    connect(thumbnailJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
-            this, TQT_SLOT(slotGotThumbnail(const KFileItem*, const TQPixmap&)));
+    connect(thumbnailJob, TQ_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
+            this, TQ_SLOT(slotGotThumbnail(const KFileItem*, const TQPixmap&)));
 }
 
 void ImagesList::slotGotThumbnail(const KFileItem *item, const TQPixmap& pix)
