@@ -35,7 +35,7 @@ namespace KIPIFlickrExportPlugin
 
 class FlickrLogin : public TQDialog
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
