@@ -32,7 +32,7 @@ namespace KIPIGalleryExportPlugin
 
 class GalleryWidget : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     
 public:
