@@ -35,7 +35,7 @@ class Galleries;
 
 class Plugin_GalleryExport : public KIPI::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
