@@ -79,7 +79,7 @@ void Plugin_GPSSync::setup( TQWidget* widget )
                                      "gpsimagetag",
                                      0,     
                                      this,
-                                     TQT_SLOT(slotGPSSync()),
+                                     TQ_SLOT(slotGPSSync()),
                                      actionCollection(),
                                      "gpssync"));
 
@@ -87,7 +87,7 @@ void Plugin_GPSSync::setup( TQWidget* widget )
                                      0,
                                      0,
                                      this,
-                                     TQT_SLOT(slotGPSEdit()),
+                                     TQ_SLOT(slotGPSEdit()),
                                      actionCollection(),
                                      "gpsedit"));
 
@@ -95,7 +95,7 @@ void Plugin_GPSSync::setup( TQWidget* widget )
                                      0,
                                      0,
                                      this,
-                                     TQT_SLOT(slotGPSRemove()),
+                                     TQ_SLOT(slotGPSRemove()),
                                      actionCollection(),
                                      "gpsremove"));
 
@@ -106,7 +106,7 @@ void Plugin_GPSSync::setup( TQWidget* widget )
                                      "www", // icon
                                      0,     // do never set shortcuts from plugins.
                                      this,
-                                     TQT_SLOT(slotKMLExport()),
+                                     TQ_SLOT(slotKMLExport()),
                                      actionCollection(),
                                      "kmlexport");
 
@@ -123,8 +123,8 @@ void Plugin_GPSSync::setup( TQWidget* widget )
     KIPI::ImageCollection selection = m_interface->currentSelection();
     m_action_geolocation->setEnabled( selection.isValid() && !selection.images().isEmpty() );
 
-    connect( m_interface, TQT_SIGNAL(selectionChanged(bool)),
-             m_action_geolocation, TQT_SLOT(setEnabled(bool)));
+    connect( m_interface, TQ_SIGNAL(selectionChanged(bool)),
+             m_action_geolocation, TQ_SLOT(setEnabled(bool)));
 }
 
 bool Plugin_GPSSync::checkBinaries(TQString &gpsBabelVersion)
@@ -135,7 +135,7 @@ bool Plugin_GPSSync::checkBinaries(TQString &gpsBabelVersion)
     if (!gpsBabelBinary.isAvailable()) 
     {
         KMessageBox::information(
-                     TQT_TQWIDGET(kapp->activeWindow()),
+                     kapp->activeWindow(),
                      i18n("<qt><p>Unable to find the gpsbabel executable:<br> "
                           "This program is required by this plugin to support GPS data file decoding. "
                           "Please install gpsbabel as a package from your distributor "
@@ -152,7 +152,7 @@ bool Plugin_GPSSync::checkBinaries(TQString &gpsBabelVersion)
     if (!gpsBabelBinary.versionIsRight()) 
     {
         KMessageBox::information(
-                     TQT_TQWIDGET(kapp->activeWindow()),
+                     kapp->activeWindow(),
                      i18n("<qt><p>gpsbabel executable is not up to date:<br> "
                           "The version %1 of gpsbabel have been found on your computer. "
                           "This version is too old to run properly with this plugin. "
@@ -186,7 +186,7 @@ void Plugin_GPSSync::slotGPSSync()
     */
 
     KIPIGPSSyncPlugin::GPSSyncDialog *dialog = new KIPIGPSSyncPlugin::GPSSyncDialog(
-                                               m_interface, TQT_TQWIDGET(kapp->activeWindow()));
+                                               m_interface, kapp->activeWindow());
 
     dialog->setImages( images.images() );
     dialog->show();
@@ -206,7 +206,7 @@ void Plugin_GPSSync::slotGPSEdit()
     bool hasGPSInfo = exiv2Iface.getGPSInfo(alt, lat, lng);
     KIPIGPSSyncPlugin::GPSDataContainer gpsData(alt, lat, lng, false);
 
-    KIPIGPSSyncPlugin::GPSEditDialog dlg(TQT_TQWIDGET(kapp->activeWindow()), 
+    KIPIGPSSyncPlugin::GPSEditDialog dlg(kapp->activeWindow(), 
                                          gpsData, img.fileName(), hasGPSInfo);
 
     if (dlg.exec() == KDialogBase::Accepted)
@@ -245,7 +245,7 @@ void Plugin_GPSSync::slotGPSEdit()
         if (!errorFiles.isEmpty())
         {
             KMessageBox::errorList(
-                        TQT_TQWIDGET(kapp->activeWindow()),
+                        kapp->activeWindow(),
                         i18n("Unable to save geographical coordinates into:"),
                         errorFiles,
                         i18n("Edit Geographical Coordinates"));  
@@ -261,7 +261,7 @@ void Plugin_GPSSync::slotGPSRemove()
         return;
 
     if (KMessageBox::warningYesNo(
-                     TQT_TQWIDGET(kapp->activeWindow()),
+                     kapp->activeWindow(),
                      i18n("Geographical coordinates will be definitively removed from all selected images.\n"
                           "Do you want to continue ?"),
                      i18n("Remove Geographical Coordinates")) != KMessageBox::Yes)
@@ -296,7 +296,7 @@ void Plugin_GPSSync::slotGPSRemove()
     if (!errorFiles.isEmpty())
     {
         KMessageBox::errorList(
-                    TQT_TQWIDGET(kapp->activeWindow()),
+                    kapp->activeWindow(),
                     i18n("Unable to remove geographical coordinates from:"),
                     errorFiles,
                     i18n("Remove Geographical Coordinates"));  
@@ -314,9 +314,9 @@ void Plugin_GPSSync::slotKMLExport()
     else 
     {
         KIPIGPSSyncPlugin::KMLExportConfig *kmlExportConfigGui = new KIPIGPSSyncPlugin::KMLExportConfig(
-                                                                 TQT_TQWIDGET(kapp->activeWindow()), i18n("KMLExport").ascii());
-        connect(kmlExportConfigGui, TQT_SIGNAL(okButtonClicked()), 
-                this, TQT_SLOT(slotKMLGenerate()));
+                                                                 kapp->activeWindow(), i18n("KMLExport").ascii());
+        connect(kmlExportConfigGui, TQ_SIGNAL(okButtonClicked()), 
+                this, TQ_SLOT(slotKMLGenerate()));
         kmlExportConfigGui->show();
     }
 }
