@@ -62,7 +62,7 @@ void Plugin_HelloWorld::setup( TQWidget* widget )
                                    "misc",
                                    0,	// do never set shortcuts from plugins.
                                    this,
-                                   TQT_SLOT(slotActivate()),
+                                   TQ_SLOT(slotActivate()),
                                    actionCollection(),
                                    "helloworld");
     
