@@ -236,7 +236,7 @@ struct Generator::Private {
 			return;
 		}
 		
-		TQString imageFormat = TQImageIO::imageFormat(TQT_TQIODEVICE(&imageFile));
+		TQString imageFormat = TQImageIO::imageFormat(&imageFile);
 		if (imageFormat.isEmpty()) {
 			logWarning(i18n("Format of image '%1' is unknown").arg(path));
 			return;
