@@ -37,7 +37,7 @@ namespace KIPIJPEGLossLessPlugin
 
 class ImageGrayScale : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
