@@ -41,7 +41,7 @@ namespace KIPIJPEGLossLessPlugin
 
 class ImageFlip : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
