@@ -74,7 +74,7 @@ DMessageBox::DMessageBox() : TQWidget(0, 0, WShowModal | WStyle_DialogBorder| WD
     grid->addItem(new TQSpacerItem(5, 10, TQSizePolicy::Expanding, TQSizePolicy::Minimum), 2, 0);
     grid->addItem(new TQSpacerItem(5, 10, TQSizePolicy::Expanding, TQSizePolicy::Minimum), 2, 2);
     // ---------------------------------------------------
-    connect(okButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotOkClicked()));
+    connect(okButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotOkClicked()));
     int W=500;
     int H=400;
     move(TQApplication::desktop()->width ()/2-(W/2), TQApplication::desktop()->height()/2-(H/2));
