@@ -39,7 +39,7 @@ namespace KIPIKameraKlientPlugin
 class GPCamera;
 
 class GPController : public TQObject, public TQThread {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
