@@ -25,7 +25,7 @@ namespace KIPIKameraKlientPlugin
 
 class GPMessages : public TQObject {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
     friend class GPStatus;
