@@ -95,7 +95,7 @@ IPTCCaption::IPTCCaption(TQWidget* parent)
 
     // IPTC only accept printable Ascii char.
     TQRegExp asciiRx("[\x20-\x7F]+$");
-    TQValidator *asciiValidator = new TQRegExpValidator(asciiRx, TQT_TQOBJECT(this));
+    TQValidator *asciiValidator = new TQRegExpValidator(asciiRx, this);
     
     // --------------------------------------------------------
 
@@ -165,54 +165,54 @@ IPTCCaption::IPTCCaption(TQWidget* parent)
 
     // --------------------------------------------------------
                                      
-    connect(d->captionCheck, TQT_SIGNAL(toggled(bool)),
-            d->captionEdit, TQT_SLOT(setEnabled(bool)));
+    connect(d->captionCheck, TQ_SIGNAL(toggled(bool)),
+            d->captionEdit, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->captionCheck, TQT_SIGNAL(toggled(bool)),
-            d->syncJFIFCommentCheck, TQT_SLOT(setEnabled(bool)));
+    connect(d->captionCheck, TQ_SIGNAL(toggled(bool)),
+            d->syncJFIFCommentCheck, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->captionCheck, TQT_SIGNAL(toggled(bool)),
-            d->syncHOSTCommentCheck, TQT_SLOT(setEnabled(bool)));
+    connect(d->captionCheck, TQ_SIGNAL(toggled(bool)),
+            d->syncHOSTCommentCheck, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->captionCheck, TQT_SIGNAL(toggled(bool)),
-            d->syncEXIFCommentCheck, TQT_SLOT(setEnabled(bool)));
+    connect(d->captionCheck, TQ_SIGNAL(toggled(bool)),
+            d->syncEXIFCommentCheck, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->writerCheck, TQT_SIGNAL(toggled(bool)),
-            d->writerEdit, TQT_SLOT(setEnabled(bool)));
+    connect(d->writerCheck, TQ_SIGNAL(toggled(bool)),
+            d->writerEdit, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->headlineCheck, TQT_SIGNAL(toggled(bool)),
-            d->headlineEdit, TQT_SLOT(setEnabled(bool)));
+    connect(d->headlineCheck, TQ_SIGNAL(toggled(bool)),
+            d->headlineEdit, TQ_SLOT(setEnabled(bool)));
     
-    connect(d->specialInstructionCheck, TQT_SIGNAL(toggled(bool)),
-            d->specialInstructionEdit, TQT_SLOT(setEnabled(bool)));
+    connect(d->specialInstructionCheck, TQ_SIGNAL(toggled(bool)),
+            d->specialInstructionEdit, TQ_SLOT(setEnabled(bool)));
 
     // --------------------------------------------------------
 
-    connect(d->captionCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->captionCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->writerCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->writerCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->headlineCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->headlineCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
     
-    connect(d->specialInstructionCheck, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->specialInstructionCheck, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalModified()));
 
     // --------------------------------------------------------
 
-    connect(d->captionEdit, TQT_SIGNAL(textChanged()),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->captionEdit, TQ_SIGNAL(textChanged()),
+            this, TQ_SIGNAL(signalModified()));
     
-    connect(d->specialInstructionEdit, TQT_SIGNAL(textChanged()),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->specialInstructionEdit, TQ_SIGNAL(textChanged()),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->writerEdit, TQT_SIGNAL(textChanged(const TQString &)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->writerEdit, TQ_SIGNAL(textChanged(const TQString &)),
+            this, TQ_SIGNAL(signalModified()));
 
-    connect(d->headlineEdit, TQT_SIGNAL(textChanged(const TQString &)),
-            this, TQT_SIGNAL(signalModified()));
+    connect(d->headlineEdit, TQ_SIGNAL(textChanged(const TQString &)),
+            this, TQ_SIGNAL(signalModified()));
 }
 
 IPTCCaption::~IPTCCaption()
