@@ -35,7 +35,7 @@ class IPTCCategoriesPriv;
 
 class IPTCCategories : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     
 public:
