@@ -35,7 +35,7 @@ class IPTCOriginPriv;
 
 class IPTCOrigin : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     
 public:
