@@ -198,47 +198,47 @@ KImg2mpgData::KImg2mpgData(KIPI::Interface* interface, TQWidget *parent, const c
 
   // Signal/Slot connections
 
-  connect( m_VideoTypeComboBox, TQT_SIGNAL( activated(int ) ),
-           this, TQT_SLOT( SlotPortfolioDurationChanged (int) ) );
+  connect( m_VideoTypeComboBox, TQ_SIGNAL( activated(int ) ),
+           this, TQ_SLOT( SlotPortfolioDurationChanged (int) ) );
 
-  connect( m_DurationImageSpinBox, TQT_SIGNAL( valueChanged(int ) ),
-           this, TQT_SLOT( SlotPortfolioDurationChanged (int) ) );
+  connect( m_DurationImageSpinBox, TQ_SIGNAL( valueChanged(int ) ),
+           this, TQ_SLOT( SlotPortfolioDurationChanged (int) ) );
 
-  connect( m_TransitionComboBox, TQT_SIGNAL( activated(int ) ),
-           this, TQT_SLOT( SlotPortfolioDurationChanged (int) ) );
+  connect( m_TransitionComboBox, TQ_SIGNAL( activated(int ) ),
+           this, TQ_SLOT( SlotPortfolioDurationChanged (int) ) );
 
-  connect( m_MPEGOutputBUTTONFilename, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotMPEGFilenameDialog() ) );
+  connect( m_MPEGOutputBUTTONFilename, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotMPEGFilenameDialog() ) );
 
-  connect( m_AudioInputBUTTONFilename, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotAudioFilenameDialog() ) );
+  connect( m_AudioInputBUTTONFilename, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotAudioFilenameDialog() ) );
 
-  connect( m_ImagesFilesListBox, TQT_SIGNAL( currentChanged( TQListBoxItem * ) ),
-           this, TQT_SLOT( slotImagesFilesSelected(TQListBoxItem *) ) );
+  connect( m_ImagesFilesListBox, TQ_SIGNAL( currentChanged( TQListBoxItem * ) ),
+           this, TQ_SLOT( slotImagesFilesSelected(TQListBoxItem *) ) );
 
-  connect(m_ImagesFilesListBox, TQT_SIGNAL( addedDropItems(KURL::List) ),
-          this, TQT_SLOT( slotAddDropItems(KURL::List)));
+  connect(m_ImagesFilesListBox, TQ_SIGNAL( addedDropItems(KURL::List) ),
+          this, TQ_SLOT( slotAddDropItems(KURL::List)));
 
-  connect( m_ImagesFilesButtonAdd, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotImagesFilesButtonAdd() ) );
+  connect( m_ImagesFilesButtonAdd, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotImagesFilesButtonAdd() ) );
 
-  connect( m_ImagesFilesButtonDelete, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotImagesFilesButtonDelete() ) );
+  connect( m_ImagesFilesButtonDelete, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotImagesFilesButtonDelete() ) );
 
-  connect( m_ImagesFilesButtonUp, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotImagesFilesButtonUp() ) );
+  connect( m_ImagesFilesButtonUp, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotImagesFilesButtonUp() ) );
 
-  connect( m_ImagesFilesButtonDown, TQT_SIGNAL( clicked() ),
-           this, TQT_SLOT( slotImagesFilesButtonDown() ) );
+  connect( m_ImagesFilesButtonDown, TQ_SIGNAL( clicked() ),
+           this, TQ_SLOT( slotImagesFilesButtonDown() ) );
 
-  connect(m_Encodebutton, TQT_SIGNAL(clicked()),
-          this, TQT_SLOT(slotEncode()));
+  connect(m_Encodebutton, TQ_SIGNAL(clicked()),
+          this, TQ_SLOT(slotEncode()));
 
-  connect(m_optionsbutton, TQT_SIGNAL(clicked()),
-          this, TQT_SLOT(slotOptions()));
+  connect(m_optionsbutton, TQ_SIGNAL(clicked()),
+          this, TQ_SLOT(slotOptions()));
 
-  connect(m_quitbutton, TQT_SIGNAL(clicked()),
-          this, TQT_SLOT(slotClose()));
+  connect(m_quitbutton, TQ_SIGNAL(clicked()),
+          this, TQ_SLOT(slotClose()));
 
   // About data and help button.
 
@@ -260,7 +260,7 @@ KImg2mpgData::KImg2mpgData(KIPI::Interface* interface, TQWidget *parent, const c
 
   KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
   helpMenu->menu()->removeItemAt(0);
-  helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
+  helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQ_SLOT(slotHelp()), 0, -1, 0);
   m_helpButton->setPopup( helpMenu->menu() );
 
   readSettings();
@@ -427,10 +427,10 @@ void KImg2mpgData::slotImagesFilesSelected( TQListBoxItem *item )
 
   m_thumbJob = TDEIO::filePreview( url, m_ImageLabel->width() );
 
-  connect(m_thumbJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
-           TQT_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
-  connect(m_thumbJob, TQT_SIGNAL(failed(const KFileItem*)),
-           TQT_SLOT(slotFailedPreview(const KFileItem*)));
+  connect(m_thumbJob, TQ_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
+           TQ_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
+  connect(m_thumbJob, TQ_SIGNAL(failed(const KFileItem*)),
+           TQ_SLOT(slotFailedPreview(const KFileItem*)));
 
   int index = m_ImagesFilesListBox->index ( item );
   m_label7->setText(i18n("Image no. %1").arg(index + 1));
@@ -697,11 +697,11 @@ void KImg2mpgData::slotEncode( void )
     m_CommandLine = m_CommandLine + " \"" + FileName + "\" ";
   }
 
-  connect(m_Proc, TQT_SIGNAL(processExited(TDEProcess *)),this,
-          TQT_SLOT(EncodeDone(TDEProcess*)));
+  connect(m_Proc, TQ_SIGNAL(processExited(TDEProcess *)),this,
+          TQ_SLOT(EncodeDone(TDEProcess*)));
 
-  connect(m_Proc, TQT_SIGNAL(receivedStderr(TDEProcess *,char*,int)),this,
-          TQT_SLOT(readStderr(TDEProcess*,char*,int)));
+  connect(m_Proc, TQ_SIGNAL(receivedStderr(TDEProcess *,char*,int)),this,
+          TQ_SLOT(readStderr(TDEProcess*,char*,int)));
 
   m_Img2mpgPidNum = -1;
   bool result = m_Proc->start(TDEProcess::NotifyOnExit , TDEProcess::All);
@@ -726,8 +726,8 @@ void KImg2mpgData::slotOptions( void )
   m_OptionDlg->MJBinFolderEditFilename->setText(m_MJBinFolderConfig);
   m_OptionDlg->show();
 
-  connect( m_OptionDlg, TQT_SIGNAL( okClicked () ),
-           this, TQT_SLOT( slotOptionDlgOkClicked() ));
+  connect( m_OptionDlg, TQ_SIGNAL( okClicked () ),
+           this, TQ_SLOT( slotOptionDlgOkClicked() ));
 }
 
 
@@ -748,7 +748,7 @@ void KImg2mpgData::slotOptionDlgOkClicked( void )
     m_MJBinFolderConfig.truncate(m_MJBinFolderConfig.length()-1);
 
   writeSettings();
-  CheckBinProg* CheckExternalPrograms = new CheckBinProg(TQT_TQOBJECT(this));
+  CheckBinProg* CheckExternalPrograms = new CheckBinProg(this);
   int ValRet = CheckExternalPrograms->findExecutables();
 
   m_Encodebutton->setEnabled(true);
@@ -760,8 +760,8 @@ void KImg2mpgData::slotOptionDlgOkClicked( void )
   if (ValRet == 2)
       m_AudioInputFilename->setEnabled(false);
 
-  disconnect( m_OptionDlg, TQT_SIGNAL( okClicked() ),
-              this, TQT_SLOT( slotOptionDlgOkClicked() ));
+  disconnect( m_OptionDlg, TQ_SIGNAL( okClicked() ),
+              this, TQ_SLOT( slotOptionDlgOkClicked() ));
 }
 
 
