@@ -63,7 +63,7 @@ void Plugin_Mpegencoder::setup( TQWidget* widget )
                                        "video-x-generic",
                                        0,
                                        this,
-                                       TQT_SLOT(slotActivate()),
+                                       TQ_SLOT(slotActivate()),
                                        actionCollection(),
                                        "mpeg_encoder");
 
@@ -85,7 +85,7 @@ void Plugin_Mpegencoder::slotActivate()
     }
 
     KIPIMPEGEncoderPlugin::KImg2mpgData *MPEGconverterDialog =
-                           new KIPIMPEGEncoderPlugin::KImg2mpgData( interface, TQT_TQWIDGET(kapp->activeWindow()) );
+                           new KIPIMPEGEncoderPlugin::KImg2mpgData( interface, kapp->activeWindow() );
 
     KIPIMPEGEncoderPlugin::CheckBinProg* CheckExternalPrograms =
                            new KIPIMPEGEncoderPlugin::CheckBinProg(this);
