@@ -88,8 +88,8 @@ PicasawebTalker::PicasawebTalker( TQWidget* parent )
         m_apikey="49d585bafa0758cb5c58ab67198bf632";
         m_secret="34b39925e6273ffd";
 
-        connect(this, TQT_SIGNAL(signalError(const TQString&)),
-                this, TQT_SLOT(slotError(const TQString&)));
+        connect(this, TQ_SIGNAL(signalError(const TQString&)),
+                this, TQ_SLOT(slotError(const TQString&)));
 
         authProgressDlg=new TQProgressDialog();
     }
@@ -128,7 +128,7 @@ void PicasawebTalker::getToken(const TQString& username, const TQString& passwor
 
     TQString url = "https://www.google.com/accounts/ClientLogin";
 
-    PicasawebLogin *loginDialog = new PicasawebLogin(TQT_TQWIDGET(kapp->activeWindow()), TQString("LoginWindow"), username, password);
+    PicasawebLogin *loginDialog = new PicasawebLogin(kapp->activeWindow(), TQString("LoginWindow"), username, password);
     /*if (username!=NULL && username.length() > 0){
         //  kdDebug()<<"Showing stored username"<< username << endl;
         loginDialog->setUsername(username);
@@ -183,11 +183,11 @@ void PicasawebTalker::getToken(const TQString& username, const TQString& passwor
     m_state = FE_GETTOKEN;
     authProgressDlg->setLabelText(i18n("Getting the token"));
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_job   = job;
     m_buffer.resize(0);
@@ -225,11 +225,11 @@ void PicasawebTalker::checkToken(const TQString& /*token*/)
 
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded");
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_CHECKTOKEN;
     authProgressDlg->setLabelText(i18n("Checking if previous token is still valid"));
@@ -260,11 +260,11 @@ void PicasawebTalker::listAllAlbums() {
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );	
     job->addMetaData("customHTTPHeader", "Authorization: " + auth_string );
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)), 
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)), 
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_LISTALBUMS;
     m_job   = job;
@@ -295,11 +295,11 @@ void PicasawebTalker::getPhotoProperty(const TQString& method,const TQString& ar
     TDEIO::TransferJob* job = TDEIO::http_post(postUrl, tmp, false);
     job->addMetaData("content-type", "Content-Type: application/x-www-form-urlencoded" );	
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)), 
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)), 
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_GETPHOTOPROPERTY;
     m_job   = job;
@@ -333,11 +333,11 @@ void PicasawebTalker::addPhotoTag(const TQString& photoURI, const TQString& tag)
     job->addMetaData("content-length", TQString("Content-Length: %1").arg(addTagXML.length()));
     job->addMetaData("customHTTPHeader", "Authorization: " + auth_string );
 
-    //connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-    //        this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    //connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+    //        this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_ADDTAG;
     m_job   = job;
@@ -395,11 +395,11 @@ void PicasawebTalker::createAlbum(const TQString& albumTitle, const TQString& al
     job->addMetaData("content-length", TQString("Content-Length: %1").arg(newAlbumXML.length()));
     job->addMetaData("customHTTPHeader", "Authorization: " + auth_string );
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_CREATEALBUM;
     m_job   = job;
@@ -466,7 +466,7 @@ bool PicasawebTalker::addPhoto(const TQString& photoPath, FPhotoInfo& info,
         path = locateLocal("tmp", TQFileInfo(photoPath).baseName().stripWhiteSpace() + ".jpg");
 
         if (rescale && (image.width() > maxDim || image.height() > maxDim))
-            image = image.smoothScale(maxDim, maxDim, TQ_ScaleMin);
+            image = image.smoothScale(maxDim, maxDim, TQImage::ScaleMin);
 
         image.save(path, "JPEG", imageQuality);
 
@@ -497,11 +497,11 @@ bool PicasawebTalker::addPhoto(const TQString& photoPath, FPhotoInfo& info,
     job->addMetaData("content-type", form.contentType());	
     job->addMetaData("customHTTPHeader", "Authorization: " + auth_string );
 
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            this, TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            this, TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
 
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            this, TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            this, TQ_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = FE_ADDPHOTO;
     m_job   = job;
@@ -593,7 +593,7 @@ void PicasawebTalker::slotError(const TQString & error)
             transError=i18n("Unknown error");
     };
 
-    KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), i18n("Error Occured: %1\n We can not proceed further").arg(transError));
+    KMessageBox::error(kapp->activeWindow(), i18n("Error Occured: %1\n We can not proceed further").arg(transError));
     //kdDebug()<<"Not handling the error now will see it later"<<endl;
 }
 
