@@ -47,7 +47,7 @@ class UploadWidget;
 
 class PicasawebWidget : public UploadWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
