@@ -32,7 +32,7 @@ namespace KIPIPrintWizardPlugin
 
 class CropFrame : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
