@@ -49,7 +49,7 @@ typedef struct _TPhotoSize {
 
 class FrmPrintWizard : public FrmPrintWizardBase  
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 
 private:
