@@ -87,7 +87,7 @@ void TPhoto::loadCache()
 
   TQImage photo = loadPhoto();
 
-  m_thumbnail = new TQPixmap(TQImage( photo.scale(m_thumbnailSize, m_thumbnailSize, TQ_ScaleMin) ));
+  m_thumbnail = new TQPixmap(TQImage( photo.scale(m_thumbnailSize, m_thumbnailSize, TQImage::ScaleMin) ));
 
   if (m_size)
     delete m_size;
