@@ -149,7 +149,7 @@ BatchDialog::BatchDialog(TQWidget* /*parent*/)
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
     helpMenu->menu()->insertItem(i18n("Plugin Handbook"),
-                                 this, TQT_SLOT(slotHelp()), 0, -1, 0);
+                                 this, TQ_SLOT(slotHelp()), 0, -1, 0);
     actionButton(Help)->setPopup( helpMenu->menu() );
 
     // ---------------------------------------------------------------
@@ -159,15 +159,15 @@ BatchDialog::BatchDialog(TQWidget* /*parent*/)
     setButtonTip( Close, i18n("<p>Exit Raw Converter"));
 
     m_blinkConvertTimer = new TQTimer(this);
-    m_thread            = new ActionThread(TQT_TQOBJECT(this));
+    m_thread            = new ActionThread(this);
 
     // ---------------------------------------------------------------
 
-    connect(m_blinkConvertTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(slotConvertBlinkTimerDone()));
+    connect(m_blinkConvertTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(slotConvertBlinkTimerDone()));
 
-    connect(m_saveSettingsBox, TQT_SIGNAL(signalSaveFormatChanged()),
-            this, TQT_SLOT(slotSaveFormatChanged()));
+    connect(m_saveSettingsBox, TQ_SIGNAL(signalSaveFormatChanged()),
+            this, TQ_SLOT(slotSaveFormatChanged()));
 
     // ---------------------------------------------------------------
 
@@ -355,7 +355,7 @@ void BatchDialog::slotUser2()
     if (m_currentConvertItem)
         m_currentConvertItem->viewItem->setPixmap(1, SmallIcon("cancel"));
 
-    TQTimer::singleShot(500, this, TQT_SLOT(slotAborted()));
+    TQTimer::singleShot(500, this, TQ_SLOT(slotAborted()));
 }
 
 void BatchDialog::slotAborted()
