@@ -85,7 +85,7 @@ void Plugin_RawConverter::setup( TQWidget* widget )
                                  "rawconvertersingle",
                                  0,
                                  this,
-                                 TQT_SLOT(slotActivateSingle()),
+                                 TQ_SLOT(slotActivateSingle()),
                                  actionCollection(),
                                  "raw_converter_single");
 
@@ -93,7 +93,7 @@ void Plugin_RawConverter::setup( TQWidget* widget )
                                  "rawconverterbatch",
                                  0,
                                  this,
-                                 TQT_SLOT(slotActivateBatch()),
+                                 TQ_SLOT(slotActivateBatch()),
                                  actionCollection(),
                                  "raw_converter_batch");
 
@@ -108,11 +108,11 @@ void Plugin_RawConverter::setup( TQWidget* widget )
            return;
     }
 
-    connect( interface, TQT_SIGNAL( selectionChanged( bool ) ),
-             singleAction_, TQT_SLOT( setEnabled( bool ) ) );
+    connect( interface, TQ_SIGNAL( selectionChanged( bool ) ),
+             singleAction_, TQ_SLOT( setEnabled( bool ) ) );
 
-    connect( interface, TQT_SIGNAL( currentAlbumChanged( bool ) ),
-             batchAction_, TQT_SLOT( setEnabled( bool ) ) );
+    connect( interface, TQ_SIGNAL( currentAlbumChanged( bool ) ),
+             batchAction_, TQ_SLOT( setEnabled( bool ) ) );
 }
 
 Plugin_RawConverter::~Plugin_RawConverter()
@@ -166,14 +166,14 @@ void Plugin_RawConverter::slotActivateSingle()
 
     if (!isRAWFile(images.images()[0].path()))
     {
-        KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), 
+        KMessageBox::error(kapp->activeWindow(), 
                            i18n("\"%1\" is not a Raw file.").arg(images.images()[0].fileName()));
         return;
     }
 
     KIPIRawConverterPlugin::SingleDialog *converter = 
         new KIPIRawConverterPlugin::SingleDialog(images.images()[0].path(), 
-            TQT_TQWIDGET(kapp->activeWindow())); 
+            kapp->activeWindow()); 
 
     converter->show();
 }
@@ -198,7 +198,7 @@ void Plugin_RawConverter::slotActivateBatch()
         return;
 
     KIPIRawConverterPlugin::BatchDialog *converter =
-        new KIPIRawConverterPlugin::BatchDialog(TQT_TQWIDGET(kapp->activeWindow()));
+        new KIPIRawConverterPlugin::BatchDialog(kapp->activeWindow());
 
     KURL::List urls = images.images();
     TQStringList files;
