@@ -56,7 +56,7 @@ namespace KIPIRawConverterPlugin
 
 class RawDecodingIface : public KDcrawIface::KDcraw
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
