@@ -34,7 +34,7 @@ class SaveSettingsWidgetPriv;
 
 class SaveSettingsWidget : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     
 public:
