@@ -128,7 +128,7 @@ SingleDialog::SingleDialog(const TQString& file, TQWidget */*parent*/)
 
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
-    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQT_SLOT(slotHelp()), 0, -1, 0);
+    helpMenu->menu()->insertItem(i18n("Plugin Handbook"), this, TQ_SLOT(slotHelp()), 0, -1, 0);
     actionButton(Help)->setPopup( helpMenu->menu() );
 
     // ---------------------------------------------------------------
@@ -146,21 +146,21 @@ SingleDialog::SingleDialog(const TQString& file, TQWidget */*parent*/)
 
     m_blinkPreviewTimer = new TQTimer(this);
     m_blinkConvertTimer = new TQTimer(this);
-    m_thread            = new ActionThread(TQT_TQOBJECT(this));
+    m_thread            = new ActionThread(this);
 
     // ---------------------------------------------------------------
 
-    connect(m_blinkPreviewTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(slotPreviewBlinkTimerDone()));
+    connect(m_blinkPreviewTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(slotPreviewBlinkTimerDone()));
 
-    connect(m_blinkConvertTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(slotConvertBlinkTimerDone()));
+    connect(m_blinkConvertTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(slotConvertBlinkTimerDone()));
 
     // ---------------------------------------------------------------
 
     busy(false);
     readSettings();
-    TQTimer::singleShot(0, this, TQT_SLOT( slotIdentify() ) );
+    TQTimer::singleShot(0, this, TQ_SLOT( slotIdentify() ) );
 }
 
 SingleDialog::~SingleDialog()
