@@ -38,7 +38,7 @@ extern "C"
 #include <tdeconfig.h>
 #include <kdebug.h>
 #include <kiconloader.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdemessagebox.h>
 #include <kstandarddirs.h>
 #include <tdetempfile.h>
@@ -77,7 +77,7 @@ void Plugin_SendImages::setup( TQWidget* widget )
                                        "mail-message-new",                 // Menu icon.
                                        0,
                                        this,
-                                       TQT_SLOT(slotActivate()),
+                                       TQ_SLOT(slotActivate()),
                                        actionCollection(),
                                        "send_images");
 
@@ -94,8 +94,8 @@ void Plugin_SendImages::setup( TQWidget* widget )
     m_action_sendimages->setEnabled( selection.isValid() &&
                                    !selection.images().isEmpty() );
 
-    connect( interface, TQT_SIGNAL(selectionChanged(bool)),
-             m_action_sendimages, TQT_SLOT(setEnabled(bool)));
+    connect( interface, TQ_SIGNAL(selectionChanged(bool)),
+             m_action_sendimages, TQ_SLOT(setEnabled(bool)));
 }
 
 Plugin_SendImages::~Plugin_SendImages()
@@ -145,10 +145,10 @@ void Plugin_SendImages::customEvent(TQCustomEvent *event)
 
     if (!m_progressDlg)
     {
-        m_progressDlg = new KIPI::BatchProgressDialog(TQT_TQWIDGET(kapp->activeWindow()), i18n("Preparing images to send"));
+        m_progressDlg = new KIPI::BatchProgressDialog(kapp->activeWindow(), i18n("Preparing images to send"));
 
-        connect(m_progressDlg, TQT_SIGNAL(cancelClicked()),
-                this, TQT_SLOT(slotCancel()));
+        connect(m_progressDlg, TQ_SIGNAL(cancelClicked()),
+                this, TQ_SLOT(slotCancel()));
 
         m_current = 0;
         m_progressDlg->show();
@@ -261,8 +261,8 @@ void Plugin_SendImages::customEvent(TQCustomEvent *event)
             m_progressDlg->setButtonCancelText( i18n("&Close") );
 #endif
 
-            disconnect(m_progressDlg, TQT_SIGNAL(cancelClicked()),
-                       this, TQT_SLOT(slotCancel()));
+            disconnect(m_progressDlg, TQ_SIGNAL(cancelClicked()),
+                       this, TQ_SLOT(slotCancel()));
     
             // Create a text file with images comments if necessary.
     
