@@ -52,7 +52,7 @@ namespace KIPISimpleViewerExportPlugin
 
 class FirstRunDlg : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
