@@ -68,7 +68,7 @@ typedef int (SlideShow::*EffectMethod)(bool);
 class SlideShow : public TQWidget
 {
 
-    Q_OBJECT
+    TQ_OBJECT
   
     
 public:
