@@ -157,8 +157,8 @@ SlideShowConfig::SlideShowConfig(bool allowSelectedOnly, KIPI::Interface * inter
 
     // Host application images has comments
     if ( ! ImagesHasComments ) {
-        m_printCommentsCheckBox->setEnabled(FALSE);
-        m_tabWidget->setTabEnabled(commentsTab, FALSE);
+        m_printCommentsCheckBox->setEnabled(false);
+        m_tabWidget->setTabEnabled(commentsTab, false);
     }
     
     m_urlList = urlList;
@@ -545,10 +545,10 @@ void SlideShowConfig::slotSelection()
     {
         urlList = m_interface->currentSelection().images();
         
-        m_ImagesFilesButtonAdd->setEnabled(FALSE);
-        m_ImagesFilesButtonDelete->setEnabled(FALSE);
-        m_ImagesFilesButtonUp->setEnabled(FALSE);
-        m_ImagesFilesButtonDown->setEnabled(FALSE);
+        m_ImagesFilesButtonAdd->setEnabled(false);
+        m_ImagesFilesButtonDelete->setEnabled(false);
+        m_ImagesFilesButtonUp->setEnabled(false);
+        m_ImagesFilesButtonDown->setEnabled(false);
     }   
     else
         if (m_allFilesButton->isChecked())
@@ -563,18 +563,18 @@ void SlideShowConfig::slotSelection()
                 if (currentPath.isParentOf((*it).path()) && !((*it).path() == currentPath))
                     urlList += (*it).images();
             
-            m_ImagesFilesButtonAdd->setEnabled(FALSE);
-            m_ImagesFilesButtonDelete->setEnabled(FALSE);
-            m_ImagesFilesButtonUp->setEnabled(FALSE);
-            m_ImagesFilesButtonDown->setEnabled(FALSE);
+            m_ImagesFilesButtonAdd->setEnabled(false);
+            m_ImagesFilesButtonDelete->setEnabled(false);
+            m_ImagesFilesButtonUp->setEnabled(false);
+            m_ImagesFilesButtonDown->setEnabled(false);
         }
      
     if ( m_customButton->isChecked() )    // Custom selected
     {
-        m_ImagesFilesButtonAdd->setEnabled(TRUE);
-        m_ImagesFilesButtonDelete->setEnabled(TRUE);
-        m_ImagesFilesButtonUp->setEnabled(TRUE);
-        m_ImagesFilesButtonDown->setEnabled(TRUE);
+        m_ImagesFilesButtonAdd->setEnabled(true);
+        m_ImagesFilesButtonDelete->setEnabled(true);
+        m_ImagesFilesButtonUp->setEnabled(true);
+        m_ImagesFilesButtonDown->setEnabled(true);
     }
     else
     {
