@@ -49,7 +49,7 @@ namespace KIPISlideShowPlugin
     
 class SlideShowConfig : public SlideShowConfigBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
