@@ -107,7 +107,7 @@ namespace KIPISlideShowPlugin
   class SlideShowKB : public TQGLWidget
   {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
