@@ -100,10 +100,10 @@ bool GallerySink::Connect()
     TDEIO::TransferJob* job = TDEIO::http_post(mURL, form.formData(), false);
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            TQ_SLOT(slotResult(TDEIO::Job *)));
 
     mState = GE_LOGIN;
     mpJob   = job;
@@ -126,10 +126,10 @@ void GallerySink::listAlbums()
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            TQ_SLOT(slotResult(TDEIO::Job *)));
 
     mState = GE_LISTALBUMS;
     mpJob   = job;
@@ -155,10 +155,10 @@ void GallerySink::listPhotos( const TQString& albumName )
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            TQ_SLOT(slotResult(TDEIO::Job *)));
 
     mState = GE_LISTPHOTOS;
     mpJob   = job;
@@ -193,10 +193,10 @@ void GallerySink::createAlbum( const TQString& parentAlbumName,
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            TQ_SLOT(slotResult(TDEIO::Job *)));
 
     mState = GE_CREATEALBUM;
     mpJob   = job;
@@ -233,7 +233,7 @@ bool GallerySink::addPhoto( const TQString& albumName,
         // image file - see if we need to rescale it
         if (rescale && (image.width() > maxDim || image.height() > maxDim))
         {
-            image = image.smoothScale(maxDim, maxDim, TQ_ScaleMin);
+            image = image.smoothScale(maxDim, maxDim, TQImage::ScaleMin);
             path = locateLocal("tmp", KURL(photoPath).filename());
             image.save(path, TQImageIO::imageFormat(photoPath));
 
@@ -260,10 +260,10 @@ bool GallerySink::addPhoto( const TQString& albumName,
     job->addMetaData("content-type", form.contentType());
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
-            TQT_SLOT(slotResult(TDEIO::Job *)));
+    connect(job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQ_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQ_SIGNAL(result(TDEIO::Job *)),
+            TQ_SLOT(slotResult(TDEIO::Job *)));
 
     mState = GE_ADDPHOTO;
     mpJob   = job;
